@@ -45,6 +45,7 @@ branch_type = namedtuple("branch_type", ["builds_snapshot", "builds_release",
                                          "versioned", "allowed_version_re",
                                          "debian_branch"])
 VERSION_RE = "[0-9]+\.[0-9]+(\.[0-9]+)*"  # pylint: disable=W1401
+RC_RE = "rc[1-9][0-9]*"
 
 BRANCH_TYPES = {
     "feature": branch_type(True, False, False, "^%snext$" % VERSION_RE,
@@ -52,11 +53,12 @@ BRANCH_TYPES = {
     "develop": branch_type(True, False, False, "^%snext$" % VERSION_RE,
                            "debian-develop"),
     "release": branch_type(True, True, True,
-                           "^(?P<bverstr>%s)rc[1-9][0-9]*$" % VERSION_RE,
+                           "^(?P<bverstr>%s)(%s)+$" % (VERSION_RE, RC_RE),
                            "debian-develop"),
     "master": branch_type(True, True, False,
                           "^%s$" % VERSION_RE, "debian"),
     "hotfix": branch_type(True, True, True,
-                          "^(?P<bverstr>^%s\.[1-9][0-9]*)$" % VERSION_RE,
+                          "^(?P<bverstr>^%s\.[1-9][0-9]*)(%s)*$" %\
+                            (VERSION_RE, RC_RE),
                           "debian")}
 BASE_VERSION_FILE = "version"
